Module: Ruby2D::CLI
- Defined in:
- lib/ruby2d/cli/usage.rb,
lib/ruby2d/cli/browser.rb,
lib/ruby2d/cli/examples.rb,
lib/ruby2d/cli/lib_files.rb,
lib/ruby2d/cli/static_server.rb
Defined Under Namespace
Modules: Browser, Examples, StaticServer, Usage
Constant Summary collapse
- LIB_FILES =
The Ruby 2D library files, in load order, that get concatenated and compiled to mruby bytecode. Single source of truth shared by the native/web app build (
cli/build.rb) and the "Try Ruby 2D" WASM build (try/build.rb) so the two lists can't drift. Includes files from subdirectories likecli/andwindow/, so it is not a plainlib/ruby2d/*.rbglob. %w[ mruby_compat cli/colorize exceptions warnings window/class_methods window/key_events window/mouse_events window/gamepad_events window/object_events gamepad window interactive renderable color audio canvas circle ellipse font image json_parser atlas_parser sprite_sheet line polygon polyline quad rectangle sprite square text bitmap_text tileset triangle button vertices dsl ].freeze