Class: Ruby2D::Window

Inherits:
Object
  • Object
show all
Defined in:
lib/ruby2d/window.rb

Defined Under Namespace

Classes: ControllerAxisEvent, ControllerButtonEvent, ControllerEvent, EventDescriptor, KeyEvent, MouseEvent

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(args = {}) ⇒ Window

Returns a new instance of Window.



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/ruby2d/window.rb', line 16

def initialize(args = {})

  # Title of the window
  @title = args[:title] || "Ruby 2D"

  # Window background color
  @background = Color.new([0.0, 0.0, 0.0, 1.0])

  # Window icon
  @icon = nil

  # Window size and characteristics
  @width  = args[:width]  || 640
  @height = args[:height] || 480
  @resizable = false
  @borderless = false
  @fullscreen = false
  @highdpi = false

  # Size of the window's viewport (the drawable area)
  @viewport_width, @viewport_height = nil, nil

  # Size of the computer's display
  @display_width, @display_height = nil, nil

  # Total number of frames that have been rendered
  @frames = 0

  # Frames per second upper limit, and the actual FPS
  @fps_cap = args[:fps_cap] || 60
  @fps = @fps_cap

  # Vertical synchronization, set to prevent screen tearing (recommended)
  @vsync = args[:vsync] || true

  # Renderable objects currently in the window, like a linear scene graph
  @objects = []

  # Entities currently in the window
  @entities = []

  # Mouse X and Y position in the window
  @mouse_x, @mouse_y = 0, 0

  # Controller axis and button mappings file
  @controller_mappings = File.expand_path('~') + "/.ruby2d/controllers.txt"

  # Event stores for class pattern
  @keys_down = []
  @keys_held = []
  @keys_up   = []
  @mouse_buttons_down = []
  @mouse_buttons_up   = []
  @mouse_scroll_event     = false
  @mouse_scroll_direction = nil
  @mouse_scroll_delta_x   = 0
  @mouse_scroll_delta_y   = 0
  @mouse_move_event   = false
  @mouse_move_delta_x = 0
  @mouse_move_delta_y = 0
  @controller_id = nil
  @controller_axes_moved   = []
  @controller_axis_left_x  = 0
  @controller_axis_left_y  = 0
  @controller_axis_right_x = 0
  @controller_axis_right_y = 0
  @controller_buttons_down = []
  @controller_buttons_up   = []

  # Unique ID for the input event being registered
  @event_key = 0

  # Registered input events
  @events = {
    key: {},
    key_down: {},
    key_held: {},
    key_up: {},
    mouse: {},
    mouse_up: {},
    mouse_down: {},
    mouse_scroll: {},
    mouse_move: {},
    controller: {},
    controller_axis: {},
    controller_button_down: {},
    controller_button_up: {}
  }

  # The window update block
  @update_proc = Proc.new {}

  # The window render block
  @render_proc = Proc.new {}

  # Detect if window is being used through the DSL or as a class instance
  unless method(:update).parameters.empty? || method(:render).parameters.empty?
    @using_dsl = true
  end

  # Whether diagnostic messages should be printed
  @diagnostics = false

  # Console mode, enabled at command line
  if RUBY_ENGINE == 'ruby'
    @console = defined?($ruby2d_console_mode) ? true : false
  else
    @console = false
  end
end

Class Method Details

.add(o) ⇒ Object



166
167
168
# File 'lib/ruby2d/window.rb', line 166

def add(o)
  DSL.window.add(o)
end

.backgroundObject



131
# File 'lib/ruby2d/window.rb', line 131

def background;      get(:background)      end

.borderlessObject



139
# File 'lib/ruby2d/window.rb', line 139

def borderless;      get(:borderless)      end

.clearObject



174
175
176
# File 'lib/ruby2d/window.rb', line 174

def clear
  DSL.window.clear
end

.closeObject



190
191
192
# File 'lib/ruby2d/window.rb', line 190

def close
  DSL.window.close
end

.currentObject



129
# File 'lib/ruby2d/window.rb', line 129

def current;         get(:window)          end

.diagnosticsObject



147
# File 'lib/ruby2d/window.rb', line 147

def diagnostics;     get(:diagnostics)     end

.display_heightObject



137
# File 'lib/ruby2d/window.rb', line 137

def display_height;  get(:display_height)  end

.display_widthObject



136
# File 'lib/ruby2d/window.rb', line 136

def display_width;   get(:display_width)   end

.fpsObject



143
# File 'lib/ruby2d/window.rb', line 143

def fps;             get(:fps)             end

.fps_capObject



144
# File 'lib/ruby2d/window.rb', line 144

def fps_cap;         get(:fps_cap)         end

.framesObject



142
# File 'lib/ruby2d/window.rb', line 142

def frames;          get(:frames)          end

.fullscreenObject



140
# File 'lib/ruby2d/window.rb', line 140

def fullscreen;      get(:fullscreen)      end

.get(sym, opts = nil) ⇒ Object



150
151
152
# File 'lib/ruby2d/window.rb', line 150

def get(sym, opts = nil)
  DSL.window.get(sym, opts)
end

.heightObject



133
# File 'lib/ruby2d/window.rb', line 133

def height;          get(:height)          end

.highdpiObject



141
# File 'lib/ruby2d/window.rb', line 141

def highdpi;         get(:highdpi)         end

.mouse_xObject



145
# File 'lib/ruby2d/window.rb', line 145

def mouse_x;         get(:mouse_x)         end

.mouse_yObject



146
# File 'lib/ruby2d/window.rb', line 146

def mouse_y;         get(:mouse_y)         end

.off(event_descriptor) ⇒ Object



162
163
164
# File 'lib/ruby2d/window.rb', line 162

def off(event_descriptor)
  DSL.window.off(event_descriptor)
end

.on(event, &proc) ⇒ Object



158
159
160
# File 'lib/ruby2d/window.rb', line 158

def on(event, &proc)
  DSL.window.on(event, &proc)
end

.remove(o) ⇒ Object



170
171
172
# File 'lib/ruby2d/window.rb', line 170

def remove(o)
  DSL.window.remove(o)
end

.render(&proc) ⇒ Object



182
183
184
# File 'lib/ruby2d/window.rb', line 182

def render(&proc)
  DSL.window.render(&proc)
end

.resizableObject



138
# File 'lib/ruby2d/window.rb', line 138

def resizable;       get(:resizable)       end

.screenshot(opts = nil) ⇒ Object



148
# File 'lib/ruby2d/window.rb', line 148

def screenshot(opts = nil); get(:screenshot, opts) end

.set(opts) ⇒ Object



154
155
156
# File 'lib/ruby2d/window.rb', line 154

def set(opts)
  DSL.window.set(opts)
end

.showObject



186
187
188
# File 'lib/ruby2d/window.rb', line 186

def show
  DSL.window.show
end

.titleObject



130
# File 'lib/ruby2d/window.rb', line 130

def title;           get(:title)           end

.update(&proc) ⇒ Object



178
179
180
# File 'lib/ruby2d/window.rb', line 178

def update(&proc)
  DSL.window.update(&proc)
end

.viewport_heightObject



135
# File 'lib/ruby2d/window.rb', line 135

def viewport_height; get(:viewport_height) end

.viewport_widthObject



134
# File 'lib/ruby2d/window.rb', line 134

def viewport_width;  get(:viewport_width)  end

.widthObject



132
# File 'lib/ruby2d/window.rb', line 132

def width;           get(:width)           end

Instance Method Details

#add(o) ⇒ Object

Add an object to the window



252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/ruby2d/window.rb', line 252

def add(o)
  case o
  when nil
    raise Error, "Cannot add '#{o.class}' to window!"
  when Entity
    @entities.push(o)
  when Array
    o.each { |x| add_object(x) }
  else
    add_object(o)
  end
end

#add_controller_mappingsObject

Add controller mappings from file



470
471
472
473
474
# File 'lib/ruby2d/window.rb', line 470

def add_controller_mappings
  if File.exist? @controller_mappings
    ext_add_controller_mappings(@controller_mappings)
  end
end

#clearObject

Clear all objects from the window



281
282
283
284
# File 'lib/ruby2d/window.rb', line 281

def clear
  @objects.clear
  @entities.clear
end

#closeObject

Close the window



637
638
639
# File 'lib/ruby2d/window.rb', line 637

def close
  ext_close
end

#controller_axis(axis) ⇒ Object

Controller axis event method for class pattern



477
478
479
# File 'lib/ruby2d/window.rb', line 477

def controller_axis(axis)
  @controller_axes_moved.include? axis
end

#controller_button_down(btn) ⇒ Object

Controller button down event method for class pattern



482
483
484
# File 'lib/ruby2d/window.rb', line 482

def controller_button_down(btn)
  @controller_buttons_down.include? btn
end

#controller_button_up(btn) ⇒ Object

Controller button up event method for class pattern



487
488
489
# File 'lib/ruby2d/window.rb', line 487

def controller_button_up(btn)
  @controller_buttons_up.include? btn
end

#controller_callback(which, type, axis, value, button) ⇒ Object

Controller callback method, called by the native and web extentions



492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
# File 'lib/ruby2d/window.rb', line 492

def controller_callback(which, type, axis, value, button)
  # All controller events
  @events[:controller].each do |id, e|
    e.call(ControllerEvent.new(which, type, axis, value, button))
  end

  case type
  # When controller axis motion, like analog sticks
  when :axis

    # For class pattern
    unless @using_dsl
      @controller_id = which

      unless @controller_axes_moved.include? axis
        @controller_axes_moved << axis
      end

      case axis
      when :left_x
        @controller_axis_left_x = value
      when :left_y
        @controller_axis_left_y = value
      when :right_x
        @controller_axis_right_x = value
      when :right_y
        @controller_axis_right_y = value
      end
    end

    # Call event handler
    @events[:controller_axis].each do |id, e|
      e.call(ControllerAxisEvent.new(which, axis, value))
    end
  # When controller button is pressed
  when :button_down
    # For class pattern
    unless @using_dsl
      @controller_id = which
      unless @controller_buttons_down.include? button
        @controller_buttons_down << button
      end
    end

    # Call event handler
    @events[:controller_button_down].each do |id, e|
      e.call(ControllerButtonEvent.new(which, button))
    end
  # When controller button is released
  when :button_up
    # For class pattern
    unless @using_dsl
      @controller_id = which
      unless @controller_buttons_up.include? button
        @controller_buttons_up << button
      end
    end

    # Call event handler
    @events[:controller_button_up].each do |id, e|
      e.call(ControllerButtonEvent.new(which, button))
    end
  end
end

#get(sym, opts = nil) ⇒ Object

Retrieve an attribute of the window



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/ruby2d/window.rb', line 198

def get(sym, opts = nil)
  case sym
  when :window;          self
  when :title;           @title
  when :background;      @background
  when :width;           @width
  when :height;          @height
  when :viewport_width;  @viewport_width
  when :viewport_height; @viewport_height
  when :display_width, :display_height
    ext_get_display_dimensions
    if sym == :display_width
      @display_width
    else
      @display_height
    end
  when :resizable;       @resizable
  when :borderless;      @borderless
  when :fullscreen;      @fullscreen
  when :highdpi;         @highdpi
  when :frames;          @frames
  when :fps;             @fps
  when :fps_cap;         @fps_cap
  when :mouse_x;         @mouse_x
  when :mouse_y;         @mouse_y
  when :diagnostics;     @diagnostics
  when :screenshot;      screenshot(opts)
  end
end

#key_callback(type, key) ⇒ Object

Key callback method, called by the native and web extentions



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/ruby2d/window.rb', line 334

def key_callback(type, key)
  key = key.downcase

  # All key events
  @events[:key].each do |id, e|
    e.call(KeyEvent.new(type, key))
  end

  case type
  # When key is pressed, fired once
  when :down
    # For class pattern
    unless @using_dsl
      unless @keys_down.include? key
        @keys_down << key
      end
    end

    # Call event handler
    @events[:key_down].each do |id, e|
      e.call(KeyEvent.new(type, key))
    end
  # When key is being held down, fired every frame
  when :held
    # For class pattern
    unless @using_dsl
      unless @keys_held.include? key
        @keys_held << key
      end
    end

    # Call event handler
    @events[:key_held].each do |id, e|
      e.call(KeyEvent.new(type, key))
    end
  # When key released, fired once
  when :up
    # For class pattern
    unless @using_dsl
      unless @keys_up.include? key
        @keys_up << key
      end
    end

    # Call event handler
    @events[:key_up].each do |id, e|
      e.call(KeyEvent.new(type, key))
    end
  end
end

#key_down(key) ⇒ Object

Key down event method for class pattern



319
320
321
# File 'lib/ruby2d/window.rb', line 319

def key_down(key)
  @keys_down.include? key
end

#key_held(key) ⇒ Object

Key held event method for class pattern



324
325
326
# File 'lib/ruby2d/window.rb', line 324

def key_held(key)
  @keys_held.include? key
end

#key_up(key) ⇒ Object

Key up event method for class pattern



329
330
331
# File 'lib/ruby2d/window.rb', line 329

def key_up(key)
  @keys_up.include? key
end

#mouse_callback(type, button, direction, x, y, delta_x, delta_y) ⇒ Object

Mouse callback method, called by the native and web extentions



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/ruby2d/window.rb', line 406

def mouse_callback(type, button, direction, x, y, delta_x, delta_y)
  # All mouse events
  @events[:mouse].each do |id, e|
    e.call(MouseEvent.new(type, button, direction, x, y, delta_x, delta_y))
  end

  case type
  # When mouse button pressed
  when :down
    # For class pattern
    unless @using_dsl
      unless @mouse_buttons_down.include? button
        @mouse_buttons_down << button
      end
    end

    # Call event handler
    @events[:mouse_down].each do |id, e|
      e.call(MouseEvent.new(type, button, nil, x, y, nil, nil))
    end
  # When mouse button released
  when :up
    # For class pattern
    unless @using_dsl
      unless @mouse_buttons_up.include? button
        @mouse_buttons_up << button
      end
    end

    # Call event handler
    @events[:mouse_up].each do |id, e|
      e.call(MouseEvent.new(type, button, nil, x, y, nil, nil))
    end
  # When mouse motion / movement
  when :scroll
    # For class pattern
    unless @using_dsl
      @mouse_scroll_event     = true
      @mouse_scroll_direction = direction
      @mouse_scroll_delta_x   = delta_x
      @mouse_scroll_delta_y   = delta_y
    end

    # Call event handler
    @events[:mouse_scroll].each do |id, e|
      e.call(MouseEvent.new(type, nil, direction, nil, nil, delta_x, delta_y))
    end
  # When mouse scrolling, wheel or trackpad
  when :move
    # For class pattern
    unless @using_dsl
      @mouse_move_event   = true
      @mouse_move_delta_x = delta_x
      @mouse_move_delta_y = delta_y
    end

    # Call event handler
    @events[:mouse_move].each do |id, e|
      e.call(MouseEvent.new(type, nil, nil, x, y, delta_x, delta_y))
    end
  end
end

#mouse_down(btn) ⇒ Object

Mouse down event method for class pattern



386
387
388
# File 'lib/ruby2d/window.rb', line 386

def mouse_down(btn)
  @mouse_buttons_down.include? btn
end

#mouse_moveObject

Mouse move event method for class pattern



401
402
403
# File 'lib/ruby2d/window.rb', line 401

def mouse_move
  @mouse_move_event
end

#mouse_scrollObject

Mouse scroll event method for class pattern



396
397
398
# File 'lib/ruby2d/window.rb', line 396

def mouse_scroll
  @mouse_scroll_event
end

#mouse_up(btn) ⇒ Object

Mouse up event method for class pattern



391
392
393
# File 'lib/ruby2d/window.rb', line 391

def mouse_up(btn)
  @mouse_buttons_up.include? btn
end

#new_event_keyObject

Generate a new event key (ID)



299
300
301
# File 'lib/ruby2d/window.rb', line 299

def new_event_key
  @event_key = @event_key.next
end

#off(event_descriptor) ⇒ Object

Remove an event handler



314
315
316
# File 'lib/ruby2d/window.rb', line 314

def off(event_descriptor)
  @events[event_descriptor.type].delete(event_descriptor.id)
end

#on(event, &proc) ⇒ Object

Set an event handler



304
305
306
307
308
309
310
311
# File 'lib/ruby2d/window.rb', line 304

def on(event, &proc)
  unless @events.has_key? event
    raise Error, "`#{event}` is not a valid event type"
  end
  event_id = new_event_key
  @events[event][event_id] = proc
  EventDescriptor.new(event, event_id)
end

#remove(o) ⇒ Object

Remove an object from the window



266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/ruby2d/window.rb', line 266

def remove(o)
  if o == nil
    raise Error, "Cannot remove '#{o.class}' from window!"
  end

  collection = o.class.ancestors.include?(Ruby2D::Entity) ? @entities : @objects
  if i = collection.index(o)
    collection.delete_at(i)
    true
  else
    false
  end
end

#render(&proc) ⇒ Object

Set the render callback



293
294
295
296
# File 'lib/ruby2d/window.rb', line 293

def render(&proc)
  @render_proc = proc
  true
end

#render_callbackObject

Render callback method, called by the native and web extentions



604
605
606
607
608
609
610
611
612
613
614
615
# File 'lib/ruby2d/window.rb', line 604

def render_callback
  unless @using_dsl
    render
  end

  @render_proc.call

  # Run render method on all entities
  @entities.each do |e|
    e.render
  end
end

#screenshot(path) ⇒ Object

Take screenshot



623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/ruby2d/window.rb', line 623

def screenshot(path)
  if path
    ext_screenshot(path)
  else
    if RUBY_ENGINE == 'ruby'
      time = Time.now.utc.strftime '%Y-%m-%d--%H-%M-%S'
    else
      time = Time.now.utc.to_i
    end
    ext_screenshot("./screenshot-#{time}.png")
  end
end

#set(opts) ⇒ Object

Set a window attribute



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/ruby2d/window.rb', line 229

def set(opts)
  # Store new window attributes, or ignore if nil
  @title           = opts[:title]           || @title
  if Color.is_valid? opts[:background]
    @background    = Color.new(opts[:background])
  end
  @icon            = opts[:icon]            || @icon
  @width           = opts[:width]           || @width
  @height          = opts[:height]          || @height
  @fps_cap         = opts[:fps_cap]         || @fps_cap
  @viewport_width  = opts[:viewport_width]  || @viewport_width
  @viewport_height = opts[:viewport_height] || @viewport_height
  @resizable       = opts[:resizable]       || @resizable
  @borderless      = opts[:borderless]      || @borderless
  @fullscreen      = opts[:fullscreen]      || @fullscreen
  @highdpi         = opts[:highdpi]         || @highdpi
  unless opts[:diagnostics].nil?
    @diagnostics = opts[:diagnostics]
    ext_diagnostics(@diagnostics)
  end
end

#showObject

Show the window



618
619
620
# File 'lib/ruby2d/window.rb', line 618

def show
  ext_show
end

#update(&proc) ⇒ Object

Set the update callback



287
288
289
290
# File 'lib/ruby2d/window.rb', line 287

def update(&proc)
  @update_proc = proc
  true
end

#update_callbackObject

Update callback method, called by the native and web extentions



558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
# File 'lib/ruby2d/window.rb', line 558

def update_callback
  unless @using_dsl
    update
  end

  @update_proc.call

  # Run update method on all entities
  @entities.each do |e|
    e.update
  end

  # Accept and eval commands if in console mode
  if @console
    if STDIN.ready?
      cmd = STDIN.gets
      begin
        res = eval(cmd, TOPLEVEL_BINDING)
        STDOUT.puts "=> #{res.inspect}"
        STDOUT.flush
      rescue SyntaxError => se
        STDOUT.puts se
        STDOUT.flush
      rescue Exception => e
        STDOUT.puts e
        STDOUT.flush
      end
    end
  end

  # Clear inputs if using class pattern
  unless @using_dsl
    @keys_down.clear
    @keys_held.clear
    @keys_up.clear
    @mouse_buttons_down.clear
    @mouse_buttons_up.clear
    @mouse_scroll_event = false
    @mouse_move_event = false
    @controller_axes_moved.clear
    @controller_buttons_down.clear
    @controller_buttons_up.clear
  end
end